[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/ambv/black)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![CodeFactor](https://www.codefactor.io/repository/github/bastienboutonnet/sheetwork/badge)](https://www.codefactor.io/repository/github/bastienboutonnet/sheetwork)
[![codecov](https://codecov.io/gh/bastienboutonnet/sheetwork/branch/dev%2Fnicolas_jaar/graph/badge.svg)](https://codecov.io/gh/bastienboutonnet/sheetwork)
![Sheetwork Build](https://github.com/bastienboutonnet/sheetwork/workflows/Sheetwork%20CI/badge.svg)

Package Version: `v1.0.0a12`

# sheetwork 💩🤦

A handy package to load Google Sheets to Snowflake

Performs some cleanups on column names and string (such as removing trailing spaces etc.)

**BIG DISCLAIMER** sheetwork is still very early. Do not use in production jobs unless you tested it extensively and know whether it does what you want it to do!

## Documentation
Head over to the [official documentation](https://bastienboutonnet.gitbook.io/sheetwork/) to learn about:
- how to set up sheetwork
- how to use sheetwork
